print(" I recently updated the name of the library I published as 'pyerualjetwork' to 'anaplan.'\n However, due to copyright issues and branding concerns, I have decided to revert to the original name, 'pyerualjetwork'.\n From now on, you can access the library by installing version pyerualjetwork(3.3.4) using the command 'pip install pyerualjetwork', replacing the current 'anaplan(2.5.3)' modules.\n Anaplan library name changed to 'PyerualJetwork'. Please use this: pip install pyerualjetwork")